@@ -60,6 +60,22 @@ def _ast_import(tree):
     return ast.Import(names=[ast.alias(name=str(x), asname=None) for x in c])
 
 
+def _ast_import_from(tree):
+    i = tree.get_invocation()
+    c = i['args']
+    mod = c.pop(0)
+    return ast.ImportFrom(
+        module=str(mod),
+        names=[
+            ast.alias(
+                name=str(x),
+                asname=None
+            ) for x in c
+        ],
+        level=0
+    )
+
+
 def _ast_if(node, children, obj):
     cond = children.pop(0)
     true = children.pop(0)
@@ -133,6 +149,9 @@ class AST27Converter(object):
             "def": self._def,
             "import": _ast_import,
 
+            "import_from": _ast_import_from,  # Remember, "-" --> "_"
+            "decorate_with": self._ast_decorate,
+
             "while": self._ast_while,
 
             "doseq": self._ast_for,
@@ -159,6 +178,15 @@ class AST27Converter(object):
             kwargs=None
         )
 
+    def _ast_decorate(self, node):
+        i = node.get_invocation()
+        c = i['args']
+        meth = c.pop(-1)
+        fn = self.render(meth)
+        for chile in c:
+            fn.decorator_list.append(self.render(chile))
+
+        return fn
 
     def _def(self, node):
         """ For the `def` operator """
