@@ -28,6 +28,9 @@ def _resolve_atom(value, self):
     except ValueError:
         pass
 
+    # LISP Variants have a tendency to use "-" in symbols n' shit.
+    value = value.replace("-", "_")
+
     return _mangle(HYSymbol(value))
 
 
@@ -65,6 +68,7 @@ class Comment(State):
 
 class Idle(State):
     def p(self, x):
+        if x == "#": return HashExpression
         if x == ";": return Comment
         if x == "(": return Expression
         if x in WHITESPACE: return
@@ -72,6 +76,13 @@ class Idle(State):
         raise LexException("Unknown char: %s" % (x))
 
 
+class HashExpression(State):
+    def p(self, x):
+        if x == "!": return Comment
+
+        raise LexException("Unknwon Hash modifier - %s" % (x))
+
+
 class Expression(State):
     def enter(self):
         self.nodes = HYExpression([])
